summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2000-05-12 15:32:37 +0000
committerwrowe <wrowe@13f79535-47bb-0310-9956-ffa450edef68>2000-05-12 15:32:37 +0000
commitabfc36597001c4f586373496a83e1d1b8095d2b3 (patch)
treefc0772c45724f4039e04f3c161e1cb2dec051ece
parentc1dbb8d3d23b3a8a084ccb4bdfab4ebe5d54e87b (diff)
downloadlibapr-abfc36597001c4f586373496a83e1d1b8095d2b3.tar.gz
Create a true misc.c for ap_get_oslevel and ap_load_dll_func,
and clean up the naming of the entire LoadLateDll declaration. git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@60040 13f79535-47bb-0310-9956-ffa450edef68
-rw-r--r--apr.dsp4
-rw-r--r--aprlib.dsp4
-rw-r--r--misc/win32/misc.c137
-rw-r--r--misc/win32/misc.h28
-rw-r--r--misc/win32/start.c80
5 files changed, 159 insertions, 94 deletions
diff --git a/apr.dsp b/apr.dsp
index b4ab27611..05fac6e52 100644
--- a/apr.dsp
+++ b/apr.dsp
@@ -162,6 +162,10 @@ SOURCE=.\locks\win32\locks.c
# End Source File
# Begin Source File
+SOURCE=.\misc\win32\misc.c
+# End Source File
+# Begin Source File
+
SOURCE=.\misc\win32\names.c
# End Source File
# Begin Source File
diff --git a/aprlib.dsp b/aprlib.dsp
index b4ab27611..05fac6e52 100644
--- a/aprlib.dsp
+++ b/aprlib.dsp
@@ -162,6 +162,10 @@ SOURCE=.\locks\win32\locks.c
# End Source File
# Begin Source File
+SOURCE=.\misc\win32\misc.c
+# End Source File
+# Begin Source File
+
SOURCE=.\misc\win32\names.c
# End Source File
# Begin Source File
diff --git a/misc/win32/misc.c b/misc/win32/misc.c
new file mode 100644
index 000000000..79235604f
--- /dev/null
+++ b/misc/win32/misc.c
@@ -0,0 +1,137 @@
+/* ====================================================================
+ * The Apache Software License, Version 1.1
+ *
+ * Copyright (c) 2000 The Apache Software Foundation. All rights
+ * reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright
+ * notice, this list of conditions and the following disclaimer.
+ *
+ * 2. Redistributions in binary form must reproduce the above copyright
+ * notice, this list of conditions and the following disclaimer in
+ * the documentation and/or other materials provided with the
+ * distribution.
+ *
+ * 3. The end-user documentation included with the redistribution,
+ * if any, must include the following acknowledgment:
+ * "This product includes software developed by the
+ * Apache Software Foundation (http://www.apache.org/)."
+ * Alternately, this acknowledgment may appear in the software itself,
+ * if and wherever such third-party acknowledgments normally appear.
+ *
+ * 4. The names "Apache" and "Apache Software Foundation" must
+ * not be used to endorse or promote products derived from this
+ * software without prior written permission. For written
+ * permission, please contact apache@apache.org.
+ *
+ * 5. Products derived from this software may not be called "Apache",
+ * nor may "Apache" appear in their name, without prior written
+ * permission of the Apache Software Foundation.
+ *
+ * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
+ * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED. IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
+ * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
+ * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+ * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
+ * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ * ====================================================================
+ *
+ * This software consists of voluntary contributions made by many
+ * individuals on behalf of the Apache Software Foundation. For more
+ * information on the Apache Software Foundation, please see
+ * <http://www.apache.org/>.
+ */
+
+#include "apr_private.h"
+#include "misc.h"
+
+ap_status_t ap_get_oslevel(ap_pool_t *cont, ap_oslevel_e *level)
+{
+ static OSVERSIONINFO oslev;
+ static unsigned int servpack = 0;
+ static BOOL first = TRUE;
+ char *pservpack;
+
+ if (first) {
+ first = FALSE;
+ oslev.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
+ GetVersionEx(&oslev);
+ if (oslev.dwPlatformId == VER_PLATFORM_WIN32_NT) {
+ for (pservpack = oslev.szCSDVersion;
+ *pservpack && !isdigit(*pservpack); pservpack++)
+ ;
+ if (*pservpack)
+ servpack = atoi(pservpack);
+ }
+ }
+ if (oslev.dwPlatformId == VER_PLATFORM_WIN32_NT) {
+ if (oslev.dwMajorVersion == 5) {
+ (*level) = APR_WIN_2000;
+ }
+ else if (oslev.dwMajorVersion == 4) {
+ if (servpack >= 6) {
+ (*level) = APR_WIN_NT_4_SP6;
+ }
+ else if (servpack >= 4) {
+ (*level) = APR_WIN_NT_4_SP4;
+ }
+ else if (servpack >= 3) {
+ (*level) = APR_WIN_NT_4_SP3;
+ }
+ else if (servpack >= 2) {
+ (*level) = APR_WIN_NT_4_SP2;
+ }
+ else {
+ (*level) = APR_WIN_NT_4;
+ }
+ }
+ else {
+ (*level) = APR_WIN_NT;
+ }
+ return APR_SUCCESS;
+ }
+ else if (oslev.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS) {
+ if (oslev.dwMinorVersion == 0) {
+ (*level) = APR_WIN_95;
+ return APR_SUCCESS;
+ }
+ else if (oslev.dwMinorVersion > 0) {
+ (*level) = APR_WIN_98;
+ return APR_SUCCESS;
+ }
+ }
+ return APR_EEXIST;
+}
+
+
+/* This is the helper code to resolve late bound entry points
+ * missing from one or more releases of the Win32 API
+ */
+
+static const char* const lateDllName[DLL_defined] = {
+ "kernel32", "advapi32", "mswsock", "ws2_32" };
+static HMODULE lateDllHandle[DLL_defined] = {
+ NULL, NULL, NULL, NULL };
+
+FARPROC ap_load_dll_func(ap_dlltoken_e fnLib, char* fnName, int ordinal)
+{
+ if (!lateDllHandle[fnLib]) {
+ lateDllHandle[fnLib] = LoadLibrary(lateDllName[fnLib]);
+ if (!lateDllHandle[fnLib])
+ return NULL;
+ }
+ if (ordinal)
+ return GetProcAddress(lateDllHandle[fnLib], (char *) ordinal);
+ else
+ return GetProcAddress(lateDllHandle[fnLib], fnName);
+}
diff --git a/misc/win32/start.c b/misc/win32/start.c
index a780edf04..fa35f8f26 100644
--- a/misc/win32/start.c
+++ b/misc/win32/start.c
@@ -96,64 +96,6 @@ ap_status_t ap_destroy_context(ap_pool_t *cont)
return APR_SUCCESS;
}
-ap_status_t ap_get_oslevel(ap_pool_t *cont, ap_oslevel_e *level)
-{
- static OSVERSIONINFO oslev;
- static unsigned int servpack = 0;
- static BOOL first = TRUE;
- char *pservpack;
-
- if (first) {
- first = FALSE;
- oslev.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
- GetVersionEx(&oslev);
- if (oslev.dwPlatformId == VER_PLATFORM_WIN32_NT) {
- for (pservpack = oslev.szCSDVersion;
- *pservpack && !isdigit(*pservpack); pservpack++)
- ;
- if (*pservpack)
- servpack = atoi(pservpack);
- }
- }
- if (oslev.dwPlatformId == VER_PLATFORM_WIN32_NT) {
- if (oslev.dwMajorVersion == 5) {
- (*level) = APR_WIN_2000;
- }
- else if (oslev.dwMajorVersion == 4) {
- if (servpack >= 6) {
- (*level) = APR_WIN_NT_4_SP6;
- }
- else if (servpack >= 4) {
- (*level) = APR_WIN_NT_4_SP4;
- }
- else if (servpack >= 3) {
- (*level) = APR_WIN_NT_4_SP3;
- }
- else if (servpack >= 2) {
- (*level) = APR_WIN_NT_4_SP2;
- }
- else {
- (*level) = APR_WIN_NT_4;
- }
- }
- else {
- (*level) = APR_WIN_NT;
- }
- return APR_SUCCESS;
- }
- else if (oslev.dwPlatformId == VER_PLATFORM_WIN32_WINDOWS) {
- if (oslev.dwMinorVersion == 0) {
- (*level) = APR_WIN_95;
- return APR_SUCCESS;
- }
- else if (oslev.dwMinorVersion > 0) {
- (*level) = APR_WIN_98;
- return APR_SUCCESS;
- }
- }
- return APR_EEXIST;
-}
-
ap_status_t ap_set_userdata(void *data, char *key,
ap_status_t (*cleanup) (void *),
ap_pool_t *cont)
@@ -208,28 +150,6 @@ ap_status_t ap_get_userdata(void **data, char *key, ap_pool_t *cont)
return APR_ENOPOOL;
}
-/* This is the helper code to resolve late bound entry points
- * missing from one or more releases of the Win32 API
- */
-
-static const char* const lateDllName[DLL_defined] = {
- "kernel32", "advapi32", "mswsock", "ws2_32" };
-static HMODULE lateDllHandle[DLL_defined] = {
- NULL, NULL, NULL, NULL };
-
-FARPROC LoadLateDllFunc(ap_dlltoken_e fnLib, char* fnName, int ordinal)
-{
- if (!lateDllHandle[fnLib]) {
- lateDllHandle[fnLib] = LoadLibrary(lateDllName[fnLib]);
- if (!lateDllHandle[fnLib])
- return NULL;
- }
- if (ordinal)
- return GetProcAddress(lateDllHandle[fnLib], (char *) ordinal);
- else
- return GetProcAddress(lateDllHandle[fnLib], fnName);
-}
-
/* This puts one thread in a Listen for signals mode */
ap_status_t ap_initialize(void)
{
diff --git a/misc/win32/misc.h b/misc/win32/misc.h
index b2d8b4f20..5ddb2d2ff 100644
--- a/misc/win32/misc.h
+++ b/misc/win32/misc.h
@@ -94,23 +94,23 @@ typedef enum {
DLL_defined = 4 // must define as last idx_ + 1
} ap_dlltoken_e;
-FARPROC LoadLateDllFunc(ap_dlltoken_e fnLib, char *fnName, int ordinal);
+FARPROC ap_load_dll_func(ap_dlltoken_e fnLib, char *fnName, int ordinal);
-/* The LateFunctionName call WILL fault if the function cannot be loaded */
+/* The ap_load_dll_func call WILL fault if the function cannot be loaded */
-#define DECLARE_LATE_DLL_FUNC(lib, rettype, calltype, fn, ord, args, names) \
- typedef rettype (calltype *fpt##fn) args; \
- static fpt##fn pfn##fn = NULL; \
- __inline rettype Late##fn args \
- { if (!pfn##fn) \
- pfn##fn = (fpt##fn) LoadLateDllFunc(lib, #fn, ord); \
- return (*(pfn##fn)) names; }; \
+#define AP_DECLARE_LATE_DLL_FUNC(lib, rettype, calltype, fn, ord, args, names) \
+ typedef rettype (calltype *ap_winapi_fpt_##fn) args; \
+ static ap_winapi_fpt_##fn ap_winapi_pfn_##fn = NULL; \
+ __inline rettype ap_winapi_##fn args \
+ { if (!ap_winapi_pfn_##fn) \
+ ap_winapi_pfn_##fn = (ap_winapi_fpt_##fn) ap_load_dll_func(lib, #fn, ord); \
+ return (*(ap_winapi_pfn_##fn)) names; }; \
/* Provide late bound declarations of every API function missing from
* one or more supported releases of the Win32 API
*
* lib is the enumerated token from ap_dlltoken_e, and must correspond
* to the string table entry in start.c used by the LoadLateDllFunc().
* Token names (attempt to) follow Windows.h declarations prefixed by DLL_
* in order to facilitate comparison. Use the exact declaration syntax
* and names from Windows.h to prevent ambigutity and bugs.
@@ -125,18 +125,18 @@ FARPROC LoadLateDllFunc(ap_dlltoken_e fnLib, char *fnName, int ordinal);
* In the case of non-text functions, simply #define the original name
*/
-DECLARE_LATE_DLL_FUNC(DLL_WINBASEAPI, BOOL, WINAPI, GetFileAttributesExA, 0, (
+AP_DECLARE_LATE_DLL_FUNC(DLL_WINBASEAPI, BOOL, WINAPI, GetFileAttributesExA, 0, (
IN LPCSTR lpFileName,
IN GET_FILEEX_INFO_LEVELS fInfoLevelId,
OUT LPVOID lpFileInformation),
(lpFileName, fInfoLevelId, lpFileInformation));
#undef GetFileAttributesEx
-#define GetFileAttributesEx LateGetFileAttributesExA
+#define GetFileAttributesEx ap_winapi_GetFileAttributesExA
-DECLARE_LATE_DLL_FUNC(DLL_WINBASEAPI, BOOL, WINAPI, CancelIo, 0, (
+AP_DECLARE_LATE_DLL_FUNC(DLL_WINBASEAPI, BOOL, WINAPI, CancelIo, 0, (
IN HANDLE hFile),
(hFile));
-#define CancelIo LateCancelIo
+#define CancelIo ap_winapi_CancelIo
ap_status_t ap_get_oslevel(struct ap_pool_t *, ap_oslevel_e *);
@@ -94,23 +94,23 @@ typedef enum {
*
* lib is the enumerated token from ap_dlltoken_e, and must correspond
- * to the string table entry in start.c used by the LoadLateDllFunc().
+ * to the string table entry in start.c used by the ap_load_dll_func().
* Token names (attempt to) follow Windows.h declarations prefixed by DLL_
* in order to facilitate comparison. Use the exact declaration syntax